# Coraw
Simplest cozmo raw data sender i could make.
Please note that this may not work as it is still a work in progress and i still have much to learn about this.
# Install
Install with "pip install Coraw"
#Usage
```python
import coraw

coraw.connect()
coraw.forward(2.0)
coraw.disconnect()
